slide

Function slide 

pub async fn slide(config: GlobalConfig) -> Result<Token>
Monitor all the slides.

This function will take the input config, identify the volumes and slides, and execute the sync jobs. Returns a Result indicating success or failure.