pub struct RootsetConfig {
pub keyword: String,
pub roots: Vec<PathBuf>,
}Expand description
Set of roots
This configuration is used to define a set of root paths that will contain volumes, along with the keyword each root will use.
Fields
keyword: StringKeyword to use for this rootset
roots: Vec<PathBuf>List of root absolute paths that will contain volumes